/**
 * 
 */
package com.guagua.base;

import java.util.Queue;
import java.util.concurrent.ConcurrentLinkedQueue;

import com.guagua.base.function.Function0;

/**
 * 简易的对象池工具
 * @author 徐峰
 * @param <T>
 */
public class ObjectPool <T> {
	final Queue<T> queue = new ConcurrentLinkedQueue<T>();
	final Function0<T> fn;
	final int maxCount;
	
	/**
	 * 创建一个对象池
	 * @param maxCount 对象池中最大保存对象个数
	 * @param fn 对象构建方法
	 */
	public ObjectPool(int maxCount, Function0<T> fn) {
		this.maxCount = maxCount;
		this.fn = fn;
	}
	
	/**
	 * 获取对象
	 * @return
	 * @throws Exception 
	 */
	public T get() throws Exception {
		T t = queue.poll();
		if (t == null) {
			t = fn.apply();
		}
		return t;
	}
	
	/**
	 * 释放对象
	 * @param t
	 */
	public void free(T t) {
		if (queue.size() < maxCount) {
			queue.offer(t);
		}
	}
}
