package com.guagua.base.util;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * http 相关工具
 * @author 徐峰
 */
public class HttpUtil {
	static Logger logger = LoggerFactory.getLogger(HttpUtil.class);


	/**
	 * 获取用户的真实IP
	 */
	public static String getIP(HttpServletRequest request) {
		String ip = request.getHeader("X-Forwarded-For");
		if (ip == null)
			ip = request.getHeader("X-Real-IP");
		if (ip == null)
			ip = request.getRemoteAddr();
		return ip;
	}
	
    // 主域名正则
    private static final Pattern MAIN_DOMAIN = Pattern.compile(
			"(?<=http://|\\.)[^.]*?\\.(com|cn|net|org|biz|info|cc|tv)",
			Pattern.CASE_INSENSITIVE);

	/**
	 * 得到当前服务的主域名 例如  17guagua.com、 17guagua.net 等等
	 * @param request
	 * @return
	 */
	public static String getMainDomain(HttpServletRequest request) {
		Matcher matcher = MAIN_DOMAIN.matcher(request.getHeader("Host"));
		matcher.find();
		return matcher.group();
	}
	
	/**
	 * 返回一个url的内容 
	 * @return
	 * @throws IllegalStateException 如果httpCode 不成功，即http code != 200 抛出异常 
	 */
	public static String getUrlContent(String url) throws Exception {
		return request(url).getSuccessContent();
	}
	
	/**
	 * 向一个url 发送请求，并获得信息
	 * @param url
	 * @return
	 * @throws Exception
	 */
	public static HttpResponseInfo request(String url) throws Exception {
		return request(new HttpRequestInfo().setUrl(url).setMethod(RequestMethod.GET));
	}

	public static HttpResponseInfo request(HttpRequestInfo request) throws Exception {
		
		if (request.getMethod() != RequestMethod.POST) {
          String url = request.getUrl();
          url += (url.indexOf("?") < 0 ? "?" : "&") + request.getParameterString();
          request.setUrl(url);
		}
		
		URL url = new URL(request.getUrl());
		
		HttpURLConnection conn;
		if (request.isProxy()) {
			conn = (HttpURLConnection)url.openConnection(request.getProxy());
		}
		else {
			conn = (HttpURLConnection) url.openConnection();
		}
		
		conn.setRequestMethod(request.getMethod().name());  
		conn.setUseCaches(false);
		conn.setReadTimeout(request.getTimeout());
		conn.setConnectTimeout(request.getTimeout());
		
		for (NameValuePair pair : request.getPropertyList()) {
			conn.addRequestProperty(pair.name, pair.value);
		}
		
		if (request.getMethod() == RequestMethod.POST) {
			conn.setDoOutput(true);
			conn.setDoInput(true);
			OutputStream out = conn.getOutputStream();
			out.write(request.getParameterString().getBytes());
			out.flush();
			out.close();
		}
		
		HttpResponseInfo response = new HttpResponseInfo();
		logger.info("#http_request {}", request);
		response.setCode(conn.getResponseCode());
		response.setMessage(conn.getResponseMessage());
		response.setHeaderFields(conn.getHeaderFields());
		
        StringBuilder sb = new StringBuilder();
        InputStream inputStream = response.getCode() == 200 ? conn.getInputStream() : conn.getErrorStream();
		InputStreamReader input = new InputStreamReader(inputStream, request.getResponseCharsetName());
        char[] chs = new char[1024];
        
        int readlen = 0;
		for(;;) {
			readlen = input.read(chs);
			if (readlen == -1) {
				break;
			}
        	sb.append(chs, 0, readlen);
        }
		response.setContent(sb.toString());
		inputStream.close();
		return response;
	}
}
