/**
 * 
 */
package com.guagua.base.util;

/**
 * 远端接口提供者 provider 信息。
 * @author 徐峰
 */
public class ProviderConfig {
	/** url 地址串， 可包含 %s 字符，以便添加其他信息 */
	String url;
	/** provider ip */
	String ip;
	/** provider 通讯端口 */
	Integer port;
	/** 客户身份key */
	String consumerKey;
	/** 密码 */
	String consumerSecret;
	/** 加密类型  none 不加密  oauth1 oauth1.0 加密 */
	String encryptType; 
	
	public ProviderConfig() {}
	
	public ProviderConfig(String ip, int port, String url) {
		this.ip = ip;
		this.port = port;
		this.url = url;
	}
	
	/**
	 * @param ip the ip to set
	 */
	public ProviderConfig setIp(String ip) {
		this.ip = ip;
		return this;
	}

	/**
	 * @param port the port to set
	 */
	public ProviderConfig setPort(Integer port) {
		this.port = port;
		return this;
	}

	/**
	 * @param url the url to set
	 */
	public ProviderConfig setUrl(String url) {
		this.url = url;
		return this;
	}

	/**
	 * @return the ip
	 */
	public String getIp() {
		return ip;
	}
	
	
	/**
	 * @return the port
	 */
	public int getPort() {
		if (port == null) {
			port = url.startsWith("https") ? 433 : 80;
		}
		return port;
	}
	/**
	 * @return the url
	 */
	public String getUrl(Object... args) {
		return String.format(url, args);
	}
	
	
	/**
	 * @return the consumerKey
	 */
	public String getConsumerKey() {
		return consumerKey;
	}

	/**
	 * @return the consumerSecret
	 */
	public String getConsumerSecret() {
		return consumerSecret;
	}

	/**
	 * @return the encryptType
	 */
	public String getEncryptType() {
		return encryptType;
	}

	@Override
	public String toString() {
		return ip + ":" + port + " " + url + " " + consumerKey + " " + consumerSecret;
	}

	/**
	 * 通过已有的 request 对象添加 服务器端信息
	 * @param request 
	 * @return
	 * @throws Exception 
	 */
	public HttpRequestInfo addRequestInfo(HttpRequestInfo request, Object... urlAdd) throws Exception {
		request.setUrl(getUrl(urlAdd)).proxySocketAddress(getIp(), getPort());
		String consumerKey = getConsumerKey();
		String consumerSecret = getConsumerSecret();
		if ( consumerKey == null || consumerSecret == null ){
			consumerKey = EnvironmentUtil.getConsumerKey();
			consumerSecret = EnvironmentUtil.getConsumerSecret();
		}
		request.addParameter(SecurityUtil.getOauth1Parameter(request.url, request.getMethod(), request.getParameterList(), consumerKey, consumerSecret, ""));
		return request;
	}
}
