package com.guagua.base.util;

import org.apache.commons.codec.digest.DigestUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

//import com.guagua.community.export.util.MD5;


/**
 * 字符串相关工具
 * @author 徐峰
 */
public class StringUtil {
	static Logger log = LoggerFactory.getLogger(StringUtil.class);
	
	private static final char CA[];
//	private static MD5 md5 = new MD5();
	
	static{
		CA = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/".toCharArray();
	}
	
	/** 将输入对象转换成String，输入对象为null时 返回空字符串 "" */
	public static String toStringNoNull(Object obj) {
		return obj == null ? "" : obj.toString();
	}
	
	/**
	 * 返回一个对象字符串是否为 null 或者 ""
	 * @param obj 要判断的对象
	 * @return 是否为null 或者 ""
	 */
	public static boolean isEmpty(Object obj) {
		return obj == null || obj.toString().isEmpty();
	}

	/**
	 * 取得拆分后的最后一个字符串 substringAfterLast("foo.bar.baz", ".") == "baz"
	 * @param str 要拆分的字符串
	 * @param split 拆分字符
	 * @return 最后一个字符串
	 */
	public static String substringAfterLast(String str, String split) {
		String[] strs = str.split(split);
		if (strs.length == 0) {
			return "";
		}
		return strs[strs.length - 1];
	}
    /** 
     * 连接字符串数组，将其连成一个字符串。
     * @param str	要连接的字符串数组
     * @return		连接后的字符串
     */
    public static String connect(Object[] str){
        return connect(str, "\n");
    }
    
    /** 
     * 连接字符串数组，将其连成一个字符串。
     * @param str	要连接的字符串数组
     * @param separator 两个字符串之间的分割符号
     * @return		连接后的字符串
     */
    public static String connect(Object[] str, String separator){
        if (str == null) {
            return null;
        }
        if (str.length == 0) {
            return "";
        }
        
        StringBuffer result = new StringBuffer("");
        for (int i = 0; i < str.length - 1; i++) {
            result.append(str[i]);
            result.append(separator);
        }
        result.append(str[str.length - 1]);
        
        return result.toString();
    }
    
    public static String encodeBase64(byte data[]){
        boolean lineSep = false;
        int sLen = data == null ? 0 : data.length;
        if(sLen == 0)
            return new String("");
        int eLen = (sLen / 3) * 3;
        int cCnt = (sLen - 1) / 3 + 1 << 2;
        int dLen = cCnt + (lineSep ? (cCnt - 1) / 76 << 1 : 0);
        char dArr[] = new char[dLen];
        int s = 0;
        int d = 0;
        int cc = 0;
        do
        {
            if(s >= eLen)
                break;
            int i = (data[s++] & 0xff) << 16 | (data[s++] & 0xff) << 8 | data[s++] & 0xff;
            dArr[d++] = CA[i >>> 18 & 0x3f];
            dArr[d++] = CA[i >>> 12 & 0x3f];
            dArr[d++] = CA[i >>> 6 & 0x3f];
            dArr[d++] = CA[i & 0x3f];
            if(lineSep && ++cc == 19 && d < dLen - 2)
            {
                dArr[d++] = '\r';
                dArr[d++] = '\n';
                cc = 0;
            }
        } while(true);
        int left = sLen - eLen;
        if(left > 0)
        {
            int i = (data[eLen] & 0xff) << 10 | (left != 2 ? 0 : (data[sLen - 1] & 0xff) << 2);
            dArr[dLen - 4] = CA[i >> 12];
            dArr[dLen - 3] = CA[i >>> 6 & 0x3f];
            dArr[dLen - 2] = left != 2 ? '=' : CA[i & 0x3f];
            dArr[dLen - 1] = '=';
        }
        return new String(dArr);
    }
    
    public static String getMD5OfStr(String str){
    	return DigestUtils.md5Hex(str);
//        return md5.getMD5ofStr(str);
    }
}
